==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/GLCODECOMBINATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Classe Java pour GLCODECOMBINATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GLCODECOMBINATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CODECOMBINATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GLCDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLCODECOMBINATIONID_Type", propOrder = {
    "codecombinationid",
    "glcdescription"
})
public class GLCODECOMBINATIONID_Type {

    @XmlElement(name = "CODECOMBINATIONID", required = true)
    protected AMOUNT codecombinationid;
    @XmlElement(name = "GLCDESCRIPTION")
    protected String glcdescription;

    /**
     * Obtient la valeur de la propriété codecombinationid.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getCODECOMBINATIONID() {
        return codecombinationid;
    }

    /**
     * Définit la valeur de la propriété codecombinationid.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setCODECOMBINATIONID(AMOUNT value) {
        this.codecombinationid = value;
    }

    /**
     * Obtient la valeur de la propriété glcdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLCDESCRIPTION() {
        return glcdescription;
    }

    /**
     * Définit la valeur de la propriété glcdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLCDESCRIPTION(String value) {
        this.glcdescription = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/GLCODECOMBINATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Java class for GLCODECOMBINATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GLCODECOMBINATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CODECOMBINATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GLCDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLCODECOMBINATIONID_Type", propOrder = {
    "codecombinationid",
    "glcdescription"
})
public class GLCODECOMBINATIONID_Type {

    @XmlElement(name = "CODECOMBINATIONID", required = true)
    protected AMOUNT codecombinationid;
    @XmlElement(name = "GLCDESCRIPTION")
    protected String glcdescription;

    /**
     * Gets the value of the codecombinationid property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getCODECOMBINATIONID() {
        return codecombinationid;
    }

    /**
     * Sets the value of the codecombinationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setCODECOMBINATIONID(AMOUNT value) {
        this.codecombinationid = value;
    }

    /**
     * Gets the value of the glcdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLCDESCRIPTION() {
        return glcdescription;
    }

    /**
     * Sets the value of the glcdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLCDESCRIPTION(String value) {
        this.glcdescription = value;
    }

}
